@@ -1,23 +1,11 @@
 """
-  Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-
-  Permission is hereby granted, free of charge, to any person obtaining a copy of this
-  software and associated documentation files (the "Software"), to deal in the Software
-  without restriction, including without limitation the rights to use, copy, modify,
-  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
-  permit persons to whom the Software is furnished to do so.
-
-  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
-  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
-  PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
-  OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+SPDX-License-Identifier: MIT-0
 """
 import re
 import six
-from cfnlint import CloudFormationLintRule
-from cfnlint import RuleMatch
+from cfnlint.rules import CloudFormationLintRule
+from cfnlint.rules import RuleMatch
 
 
 class Ebs(CloudFormationLintRule):
@@ -61,19 +49,21 @@ class Ebs(CloudFormationLintRule):
         matches = []
 
         results = cfn.get_resource_properties(['AWS::EC2::Instance', 'BlockDeviceMappings'])
-        results.extend(cfn.get_resource_properties(['AWS::AutoScaling::LaunchConfiguration', 'BlockDeviceMappings']))
+        results.extend(cfn.get_resource_properties(
+            ['AWS::AutoScaling::LaunchConfiguration', 'BlockDeviceMappings']))
         for result in results:
             path = result['Path']
-            for index, properties in enumerate(result['Value']):
-                virtual_name = properties.get('VirtualName')
-                ebs = properties.get('Ebs')
-                if virtual_name:
-                    # switch to regex
-                    if not re.match(r'^ephemeral[0-9]$', virtual_name):
-                        pathmessage = path[:] + [index, 'VirtualName']
-                        message = 'Property VirtualName should be of type ephemeral(n) for {0}'
-                        matches.append(
-                            RuleMatch(pathmessage, message.format('/'.join(map(str, pathmessage)))))
-                elif ebs:
-                    matches.extend(self._checkEbs(cfn, ebs, path[:] + [index, 'Ebs']))
+            if isinstance(result['Value'], list):
+                for index, properties in enumerate(result['Value']):
+                    virtual_name = properties.get('VirtualName')
+                    ebs = properties.get('Ebs')
+                    if virtual_name:
+                        # switch to regex
+                        if not re.match(r'^ephemeral[0-9]$', virtual_name):
+                            pathmessage = path[:] + [index, 'VirtualName']
+                            message = 'Property VirtualName should be of type ephemeral(n) for {0}'
+                            matches.append(
+                                RuleMatch(pathmessage, message.format('/'.join(map(str, pathmessage)))))
+                    elif ebs:
+                        matches.extend(self._checkEbs(cfn, ebs, path[:] + [index, 'Ebs']))
         return matches
